<?php // Do not delete these lines
	if ('comments.php' == basename($_SERVER['SCRIPT_FILENAME']))
		die ('Please do not load this page directly. Thanks!');

        if (!empty($post->post_password)) { // if there's a password
            if ($_COOKIE['wp-postpass_' . COOKIEHASH] != $post->post_password) {  // and it doesn't match the cookie
				?>
				
				<p class="nocomments">This post is password protected. Enter the password to view comments.<p>
				
				<?php
				return;
            }
        }
?>

<!-- You can start editing here. -->

<h3 id="comments"><?php comments_number('No Responses', 'One Response', '% Responses' );?> to &#8220;<?php the_title(); ?>&#8221;</h3> 

<p>You can subscribe to the <a href="<?php echo get_settings('siteurl'); ?>/wp-commentsrss2.php?p=<?php echo $post->ID; ?>"><abbr title="Really Simple Syndication">RSS</abbr> feed for comments on this post.</a><?php if ('open' == $post->ping_status) { ?>    You can also reply to this post directly in your weblog, <a href="<?php trackback_url(); ?>">and take advantage of the TrackBack URI</a> to record your reply in this post.<?php } ?></p>

<?php $oddcomment = 'alt'; if ($comments) : ?>

	<ol class="commentlist" id ="all_comments">
	<?php foreach ($comments as $comment) : ?>
		<li class="<?php echo $oddcomment; ?>" id="comment-<?php comment_ID() ?>">


		<?php if (function_exists('gravatar')) { 
		if ( $comment->comment_author_email || $comment->comment_author_url ) {
		if ('' != get_comment_author_url()) {
			// the commenter supplied a website URL
			echo "<a href='$comment->comment_author_url' title='Visit $comment->comment_author'>";
		} else { 
			// the commenter did not supply a website, so link to gravatars.com
			echo "<a href='http://www.gravatar.com' title='Create your own gravatar at gravatar.com!'>";
		}
		echo "<img src='";
		if ('' == $comment->comment_type) {
			// this is a regular comment, so use the commenter's email address
			echo gravatar($comment->comment_author_email);
		} elseif ( ('trackback' == $comment->comment_type) || ('pingback' == $comment->comment_type) ) {
			// this is a pingback or trackback, so use the commenter's website URL
			echo gravatar($comment->comment_author_url);
		}
		echo "' alt='' class='gravatar' /></a>";
		}
		} ?>



		<cite><?php comment_author_link() ?></cite> says:
		<?php if ($comment->comment_approved == '0') : ?>
		<em>Your comment is awaiting moderation.</em>
		<?php endif; ?>
		<br />

		<small class="commentmetadata"><a href="#comment-<?php comment_ID() ?>" title=""><?php comment_date('F jS, Y') ?> at <?php comment_time() ?></a> <?php edit_comment_link('Edit this comment','',''); ?></small>

		<?php comment_text() ?>

		</li>

	<?php /* Changes every other comment to a different class */	
		if ('alt' == $oddcomment) $oddcomment = '';
		else $oddcomment = 'alt';
	?>

	<?php endforeach; /* end for each comment */ ?>

	</ol>

<?php else : // this is displayed if there are no comments so far ?>

	<ol class="commentlist" id ="all_comments">
		<li class="stub">No comments posted yet</li>
	</ol>

<?php endif; ?>



<div id="respond-container">

<?php if ('open' == $post->comment_status) { ?>

	<h3 id="respond">Leave a comment</h3>
	
	<?php if ( get_option('comment_registration') && !$user_ID ) : ?>

		<p>You must be <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?redirect_to=<?php the_permalink(); ?>">logged in</a> to post a comment.</p>

	<?php else : ?>
	
		<p>Line and paragraph breaks automatic, e-mail address never displayed, <acronym title="Hypertext Markup Language">HTML</acronym> allowed: <code><?php echo allowed_tags(); ?></code></p>

		<form action="<?php echo get_settings('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">
		
		<?php if ( $user_ID ) : ?>
		
			<p>Logged in as <a href="<?php echo get_option('siteurl'); ?>/wp-admin/profile.php"><?php echo $user_identity; ?></a>. <a href="<?php echo get_option('siteurl'); ?>/wp-login.php?action=logout" title="Log out of this account">Logout &raquo;</a></p>
		
		<?php else : ?>
		
			<p>
			<input type="text" name="author" id="author" value="<?php echo $comment_author; ?>" size="28" tabindex="1" />
			<label for="author">Name <?php if ($req) echo "(required)"; ?></label>
			</p>
			
			<p>
			<input type="text" name="email" id="email" value="<?php echo $comment_author_email; ?>" size="28" tabindex="2" />
			<label for="email">Mail (will not be published) <?php if ($req) echo "(required)"; ?></label></p>
			
			<p>
			<input type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" size="22" tabindex="3" />
			<label for="url">Website</label>
			</p>
		
		<?php endif; ?>
		
		<p>
		<label for="comment" style="display: none">Your Comment</label>
		<?php if (function_exists('lmbbox_comment_quicktags_display')) { lmbbox_comment_quicktags_display(); } ?>
		<textarea name="comment" id="comment" cols="70" rows="10" tabindex="4"></textarea>
		</p>
		
		<p>
		<input type="hidden" name="comment_post_ID" value="<?php echo $id; ?>" />
		<input name="submit" type="submit" id="submit" tabindex="5" value="Post my comment" />
		</p>
		<?php do_action('comment_form', $post->ID); ?>
	
		</form>

	<?php endif; // If registration required and not logged in ?>

 <?php  } else { // comments are closed ?>

	<p class="nocomments">Comments are closed.</p>

<?php } // if you delete this the sky will fall on your head ?>

</div>
