/*
Theme Name: RevvedUp
Theme URI: http://rudd-o.com/projects/revvedup/
Description: The famous RevvedUp theme from Rudd-O.  please follow the instructions in the included README file after activating this theme.
Version: 1.4
Author: Manuel Amador (Rudd-O)
Author URI: http://rudd-o.com/
*/


/* color palette FIXME peinar y revisar todos estos colores */
/*
default text color: #111145;
text color on inputs: #111145;
links / headings / top border of sidebar: #0000b8;
visited links: #606077;
borders for inputs/textareas: #adade3;
input button faces: backgrounded by background-blue.png;
block quote / pre text: #616193;
block quote / pre borders: #adade3;
border for the posts: #afadeb;
post metadata / slugs / comment metadata: #999999;
text for comments: #616193;
top border for sidebar and border for navigation controls placed in content: #0000b8;
border for sidebar: #afadeb;
border for sidebar LI buttons: #afadeb;
background for tooltips: #f1f1fb;
*/

/* include utility and advertising styles */
/* this goes above because the @import statement is REQUIRED to be before all other statements */
@import url(utility-styles.css);
@import url(ad-styles.css);

/* print layout */
@media print {

	body {
		margin: 0px;
		padding: 0px;
		background-color: white;
	}

	#header .description { display: none; }
	#header h1 { display: block; font-size: 2.5em; text-align: center;}
	
	#page {
		position: relative;
		top: auto;
		left: auto;
		right: auto;
	}
	
	#content {
		margin-left: 0px;
		margin-right: 0px;
		margin-top: 0px;
	}
	
	#sidebar {
		display: none;
	}
	
	#footer {
		margin-left: 0px;
		margin-right: 0px;
		text-align: center;
	}

	#pageprintoutinfo {
		display: block;
	}

	#respond-container {
		display: none;
	}

}

/* screen layout */
@media screen {

	body {
		margin: 0px;
		padding: 0px;
		background-color: white;
		background-image: url(images/bodybackground.png);
		background-position: top left;
		background-repeat: repeat-x;
	}
	
	#header .description {
		position: absolute;
		right: 265px;
		top: 103px;
		color: #0000b8;
		font-size: 11px;
		font-style: italic;
	}
	
	#header h1 {display: none;} /* hide the header in screen displays */
	
	#page { /*where the background image is placed*/
		background-image: url(images/background.jpg);
		background-position: top right;
		background-repeat: no-repeat;
		display: block;
		position: absolute;
		top: 0px;
		right: 0px;
		left: 0px;
		height: 900px; /* a minimum height to show the entire background if the page is too short */
	}
	
	#footer {
		margin-left: 20px;
		margin-right: 450px;
		text-align: center;
		padding-left: 20px;
		padding-right: 20px;
	}
	
	#content {
		margin-left: 20px;
		margin-right: 450px; /* that'll be 410 for the sidebar,
		plus 40px for margins for the sidebar/pageborder and sidebar/content edge */
		margin-top: 120px;
	}
	
	#sidebar {
		position: absolute;
		top: 206px;
		right: 20px;
	}
	
	#pageprintoutinfo {
		display: none;
	}

}

/* typography/colors */

body {
	font-family: Tahoma, Arial, helvetica, sans-serif;
	font-size: 80%;
	color: #111145;
}

a:link, a:active {
	color: #0000b8;
}

a:visited {
	color: #606077;
}

h1, h2, h3, h4, h5, h6 {
	color: #0000b8;
	font-weight: normal;
}

h1 {font-size: 1.45em}
h2 {font-size: 1.4em}
h3 {font-size: 1.25em}
h4 {font-size: 1.1em}
h5 {font-size: 1em}

/* controls styles */

form {
	margin: 0px;
	padding: 0px;
}

textarea {
	width: 100%;
}

input[type=text], input[type=file], input[type=password], select, textarea {
	border: 1px inset #adade3;
	background: url(images/semitransparent-blue-light.png);
}

input[type=hidden] {
	border: none;
	background: none;
}

input[type=submit], input[type=button] {
	border: 1px outset #adade3;
	background: url(images/semitransparent-blue.png);
	color: #111145;
}

input[type=submit]:active, input[type=button]:active {
	border-style: inset;
}


/* inline styles */

q { quotes: "«" "»" "‹" "›"; font-style: italic; }
abbr, acronym { border-bottom: 1px dashed #111145; }
code { font-size: 125%; background: url(images/semitransparent-blue-light.png); }

/* block styles */

.pagetitle { /* the page title for pages like archives and search results */
	text-align: center;
	font-size: 2em;
}
	
hr {
	height: 1px;
	background-color: #adade3;
	border: none;
}

blockquote {
	color: #616193;
	margin: 0px;
	padding-left: 1em;
	padding-right: 1em;
	padding-top: 1em;
	padding-bottom: 1em;
	background: url(images/semitransparent-blue-light.png);
	border: 1px dashed #adade3;
	-moz-border-radius: 2mm;
	margin-top: 0.4em;
	margin-bottom: 0.4em;
	font-style: italic;
}

/* for the automated quotation linker  */
.blockquotesource { text-align: right; }

pre {
	color: #616193;
	margin: 0px;
	padding-left: 1em;
	padding-right: 1em;
	padding-top: 1em;
	padding-bottom: 1em;
	background: url(images/semitransparent-blue-light.png);
	border: 1px dashed #adade3;
	-moz-border-radius: 2mm;
	margin-top: 0.4em;
	margin-bottom: 0.4em;
	overflow: auto;
	font-size: 125%;
}

blockquote .intermediary-container  {
	background-image: url(images/blockquote-background.png);
	background-repeat: no-repeat;
	background-position: top right;
	min-height: 40px;
}

pre .intermediary-container {
	background-image: url(images/pre-background.png);
	background-repeat: no-repeat;
	background-position: top right;
	min-height: 32px;
}

/* ensure contained elements in blockquotes obey the blockquote's margins */
blockquote > *:first-child, blockquote .intermediary-container > *:first-child {
	margin-top: 0px;
	padding-top: 0px;
}

blockquote > *:last-child, blockquote .intermediary-container > *:last-child {
	margin-bottom: 0px;
	padding-bottom: 0px;
}

.center { text-align: center; } /* FIXME find out what this is for */

ul { padding-left: 1em; }
ol { padding-left: 1.4em; }


/* post styles */

.post {
	margin-bottom: 3em;
}

.post .storytitle {
	margin-top: 0px;
	margin-bottom: 0px;
}

.postmetadata { /* guess it should be in sync with .commentmetadata */
	color: #999999;
	font-family: Georgia, Times New Roman, Times, serif;
	font-style: italic;
	margin: 0px; padding: 0px;
	text-align: left;
	font-size: 1em;
}

.comments-slug { float: left; margin-right: 2em; }
.categories-slug { text-align: right; }
.categories-slug a { white-space: nowrap; }

.entry {
	margin-left: 10px;
}

/* navigation styles */

.navigation {
	display: table;
	width: 100%;
	margin-bottom: 1em;
}
.navigation .next {
	display: table-cell;
	text-align: right;
}
.navigation .previous {
	display: table-cell;
	text-align: left;
}

/* content navigation specifics */
#content .navigation {
	font-style: italic;
	margin-top: -1.5em;
 	margin-bottom: 2em;
	width: auto;
	margin-left: auto;
	margin-right: auto;
}
#content.searchresults .navigation { /* make it appear below the search box */
	margin-top: 0em;
}
#content .post + .navigation { /* on navigation controls after a post we place top/bottom borders */ 
	border-top: 2px solid #0000b8;
	border-bottom: 2px solid #0000b8;
}
#content .navigation .previous, #content .navigation .next { /* this style declaration is derived from .boxmeup */
	width: 8em;
	font-size: 1.1em;
	line-height: 0.9em;
	padding: 4px;
	padding-left: 10px;
	padding-right: 10px;
	margin-top: 3px;
	margin-bottom: 3px;
	margin-left: 0px;
	margin-right: 0px;
}

/* comment styles */

body#commentspopup {
	background: transparent;
	margin: 4px;
}

body#commentspopup #header {
	display: none;
}

.commentmetadata { /* guess it should be in sync with .postmetadata */
	color: #999999;
	font-family: Georgia, Times New Roman, Times, serif;
	font-style: italic;
	margin: 0px; padding: 0px;
	text-align: right;
	font-size: 1em;
	margin-top: 0.7em;
}

.commentlist {
	padding-left: 5mm;
}

.commentlist>li {
	background-position: right top;
	background-repeat: no-repeat;
	color: #616193;
	margin: 0;
	padding-left: 1em;
	padding-right: 1em;
	padding-top: 1em;
	padding-bottom: 1em;
	overflow: hidden;
	background: url(images/semitransparent.png);
	border: 1px outset #adade3;
	margin-bottom: 1px;
	display: block;
}

.commentlist>li.alt {
	background: url(images/semitransparent-blue-light.png);
	border: 1px outset #adade3;
}

.commentlist>li.stub {
	display: none;
}


/* nice little semitransparent boxes for consumption of the template */
/* REMEMBER: if this changes, you also need to change the themeswitcher styles as well, since those are copies of this */
ul.boxmeup {
	padding-left: 0px;
	padding: 0px;
	margin: 0px;
}
ul.boxmeup li {
	display: block;
	text-align: left;
	padding: 4px;
	padding-left: 10px;
	padding-right: 10px;
	margin-top: 3px;
	margin-bottom: 3px;
	margin-left: 0px;
	margin-right: 0px;
	border: 1px outset #afadeb;
	background: url(images/semitransparent-blue.png);
}
 /* overrides for deeper levels */
ul.boxmeup li ul { padding-left: 1.1em; }
ul.boxmeup li ul li {
	display: list-item;
	padding-top: 2px;
	padding-bottom: 2px;
	padding-left: 0em;
	padding-right: 0em;
	margin-top: 0em;
	margin-bottom: 0em;
	margin-left: 0em;
	margin-right: 0em;
	border: none;
	background: transparent;
}

/* the above are duplicated for boxchildrenup and are used to display the nice multi-category links list in the sidebar */
.boxchildrenup { margin: 0; padding: 0; } /* no margins for the container ul */
.boxchildrenup>li { display: block; margin: 0; padding: 0; } /* show li's as boxes */
/* the following are verbatim from up here */
.boxchildrenup ul {
	padding-left: 0px;
	padding: 0px;
	margin: 0px;
}
.boxchildrenup ul li {
	display: block;
	text-align: left;
	padding: 4px;
	padding-left: 10px;
	padding-right: 10px;
	margin-top: 3px;
	margin-bottom: 3px;
	margin-left: 0px;
	margin-right: 0px;
	border: 1px outset #afadeb;
	background: url(images/semitransparent-blue.png);
}
 /* overrides for deeper levels */
.boxchildrenup ul li ul { padding-left: 1.1em; }
.boxchildrenup ul li ul li {
	display: list-item;
	padding-top: 2px;
	padding-bottom: 2px;
	padding-left: 0em;
	padding-right: 0em;
	margin-top: 0em;
	margin-bottom: 0em;
	margin-left: 0em;
	margin-right: 0em;
	border: none;
	background: transparent;
}


/*********** DIRLIST STYLES **********/

#dirlist td {
vertical-align: top;
}
#dirlist img {
vertical-align: baseline;
border: none;
}

/*********** ENDDIRLIST STYLES **********/


/*********** SIDEBAR STYLES **********/

 /* this is the basic look */
#sidebar {
	background: url(images/semitransparent.png);
	font-size: 0.9em;
	border-top: 2px solid #0000b8;
	padding-bottom: 20px;
}

#sidebar > h1 {
	display: none;
}

/* #sidebar-column-layout { background: url(images/semitransparent.png); } */

/* teh pwn3d two-column layout for the sidebar */
#sidebar-column-layout { display: table; list-style: none; border: none; border-spacing: 0; padding: 0px; margin: 0px; width: 410px; }
.sidebar-column { display: table-cell; list-style: none; border: none; margin: 0px; padding: 0px; vertical-align: top; }
#sidebar-col1 { width: 200px; } /* these three widths add up to 410px */
#sidebar-col3 { width: 200px; }
#sidebar-col2 { width: 10px; }

/* the sidebar section titles */
#sidebar h2 {
	margin: 0px;
	padding: 0px;
	margin-top: 1em;
	margin-bottom: 0.3em;
	margin-left: 0em;
	margin-right: 0em;
	line-height: 1em;
	padding-top: 0.1em;
	padding-bottom: 0.1em;
}
/* tune the first titles directly under the sidebar columns */
#sidebar #sidebar-col1 > h2:first-child, #sidebar #sidebar-col3 > h2:first-child {margin-top: 0.3em;}

#sidebar-col1 h2 {
	text-align: right;
	background-position: right center;
	background-repeat: no-repeat;
	padding-right: 1.5em;
}
#sidebar-col3 h2 {
	text-align: right;
	background-position: right center;
	background-repeat: no-repeat;
	padding-right: 1.5em;
}

#sidebar h2#heading-about-this-page			{background-image: url(images/icons/about-this-page.png);}
#sidebar h2#heading-about-this-site			{background-image: url(images/icons/about-this-site.png);}
#sidebar h2#heading-archives				{background-image: url(images/icons/archives.png);}
#sidebar h2#heading-chat					{background-image: url(images/icons/chat.png);}
#sidebar #linkcat-1 h2 /* favorite sites */			{background-image: url(images/icons/favorite-sites.png);} 
#sidebar h2#heading-subscribe				{background-image: url(images/icons/favorite-sites.png);}
#sidebar h2#heading-pages					{background-image: url(images/icons/pages.png);}
#sidebar h2#heading-recent-conversations	{background-image: url(images/icons/recent-conversations.png);}
#sidebar h2#heading-related-articles			{background-image: url(images/icons/related-articles.png);}
#sidebar h2#heading-popular-articles			{background-image: url(images/icons/popular-articles.png);}
#sidebar h2#heading-donate					{background-image: url(images/icons/popular-articles.png);}


/* the sidebar section subtitles */
#sidebar h3 {
	text-align: center;
	margin: 0px;
	padding: 0px;
}

/* archives section layout */
#sidebar #archives {
	text-align: center;
	background: url(images/semitransparent-blue-light.png);
	padding: 1em;
	border: 1px inset #bbbbd2;
}
#sidebar #archives #wp-calendar {width: 100%;}
#sidebar #archives #wp-calendar #today{
	border: 1px solid #bbbbd2;
	background: white;
}

#sidebar #archives #wp-calendar caption {
	border: 1px outset #bbbbd2;
	background: url(images/semitransparent-blue-light.png);
	line-height: 2em;
}

/* searchform overrides for the sidebar */
#sidebar .searchform input[type=text] {width: 80px;}
#sidebar .searchform input[type=submit] {width: 70px;}


/********** END SIDEBAR STYLES *************/



/******** SEARCHFORM AND SEARCHPAGE STYLING ********/

.searchform {
	margin-left: auto; margin-right: auto;
	display: table;
	padding-left: 21px;
	background-image: url(images/icons/search.png);
	background-position: left center;
	background-repeat: no-repeat;
}

.searchresults .post .storytitle {
	font-size: 1.2em;
}
.searchresults .post {
	/*override to make it take less space in search results */
	margin-bottom: 2em;
}



/* ************* END SEARCHFORM STYLING ************* */




/************** THEMED OVERRIDES FOR PLUGINS *************/

/* gravatar override */
.themed .gravatar {
	float: left;
	margin-right: 0.7em;
	margin-bottom: 0.5em;
	border: 1px inset #adade3;
}


/* canary override */
.themed .loading {
	background: url(../../plugins/CanaryComment/blue_spin.gif);
	background-position: top right;
	background-repeat: no-repeat;
}


/* jp_bct override */
.themed div#bct {
	display: inline;
}


/* fancytooltips overrides */
.themed div.fancytooltip {
	background-color: #f1f1fb;
	-moz-opacity: 1.0;
	-moz-border-radius-bottomright: 0;
	-moz-border-radius-bottomleft: 2mm;
	-moz-border-radius-topright: 2mm;
	font-size: 1em;
}
.themed div.fancytooltip p {
	font-size: 1em;
}
.themed div.fancytooltip p.destination {
	font-size: 0.8em;
}


/* bsuite overrides */
.themed #bstat_pulse {
	height: 130px;
	text-align:center;
	border: 2px solid #afadeb;
	-moz-border-radius: 2mm;
	padding: 1.3em;
	padding-top: 1em;
	padding-bottom: 1em;
	background: url(images/semitransparent.png);
} 
.themed #bstat_pulse img {
	display:inline; vertical-align: middle;
	background: url(images/semitransparent-blue.png); border: none;
	margin: 0px 0px 0px 0px; padding: 0px 0px 0px 0px;
	border-top: 1px solid #adade3;
	border-bottom: 1px solid #adade3;
}
.themed .hl0 { background-color: #FFFF99 }
.themed .hl1 { background-color: #FF99FF }
.themed .hl2 { background-color: #99FFFF }
.themed .hl3 { background-color: #FF9999 }
.themed .hl4 { background-color: #9999FF }

/* the style for the div that lists the hightlighted words - this is a nearly identical but more specific copy of the class information with a nice icon */
.themed .bstat_hilite {
	padding: 1em;
	background: url(images/semitransparent-blue-light.png);
	border: 1px dashed #adade3;
	-moz-border-radius: 2mm;
	margin: 1em 0em 1em 0em; background-image: url(images/highlight.png);
	background-repeat: no-repeat; background-position: 1em 1.0em; padding-left: 2.7em;
}
.themed .searchresults .bstat_hilite {
	display: none; /* hide the highlighting box in search results because it does not look good */
}


/* quicktags overrides */
.themed #comment_quicktags {
	text-align: left;
}
/* Button Style */
.themed #comment_quicktags input.ed_button {
	background: url(images/semitransparent-blue-light.png);
	border: 1px outset #adade3;
	font-family: Georgia, "Times New Roman", Times, serif;
	margin: 1px;
	width: auto;
}
/* Button Style on focus/click */
.themed #comment_quicktags input:focus.ed_button {
	background: #FFFFFF;
	border: 1px solid #686868;
}
/* Button Lable style */
.themed #comment_quicktags #ed_strong {
	font-weight: bold;
}
/* Button Lable style */
.themed #comment_quicktags #ed_em {
	font-style: italic;
}


/* jalenack's wordspew shoutbox */
.themed #chatoutput {
	margin-top: 1.3em;
	border: 1px inset #bbbbd2;
	background: url(images/semitransparent-blue-light.png);
	font: 1em Tahoma, Arial, helvetica, sans-serif;
}
.themed #chatoutput #usersOnline { font-size: 1em; text-align: center; font-style: italic; padding-bottom: 3px; padding-top: 2px; }
.themed #chatoutput #lastMessage { padding-bottom: 2px; }
.themed #chatoutput span, .themed #chatoutput a {color: #0000b8;} /* override colors */
.themed #chatoutput, .themed #chatoutput ul#outputList li {color: #111145;} /* override colors */
.themed #chatForm input, .themed #chatForm textarea {display: inline;margin: 0;padding: 0;}
/* unfuck what the author fucked up in the first place */
.themed #chatForm input[type=hidden] { display: none; }

.themed  #chatForm input#submitchat {
	width: 28%;
	border: 1px outset #adade3;
	background: url(images/semitransparent-blue.png);
	color: #111145;
	margin: 0;
	padding: 0;
}

.themed  #chatForm input#submitchat:active {
	border-style: inset;
}




.themed  #chatForm input[type=text] {width: 67%;margin: 0;padding: 0;}


/* theme switcher and sem-subscribe ... these were copied from .boxmeup definitions above, so if .boxmeup changes, these should be updated as well */
.themed ul#themeswitcher {
	padding-left: 0px;
	padding: 0px;
	margin: 0px;
}
.themed ul#themeswitcher li {
	display: block;
	text-align: left;
	padding: 4px;
	padding-left: 10px;
	padding-right: 10px;
	margin-top: 3px;
	margin-bottom: 3px;
	margin-left: 0px;
	margin-right: 0px;
	border: 1px outset #afadeb;
	background: url(images/semitransparent-blue.png);
}

/* subscribe me style overrides */

.themed .sem_subscribe_me {
	display: block;
	text-align: right;
	margin-bottom: 1em;
}

.themed .sem_subscribe_me h2 {
	display: none;
}

.themed .sem_subscribe_me ul {
	display: inline;
	margin: 0;
	padding: 0;
}

.themed .sem_subscribe_me ul li {
	display: inline;
	list-style-type: none;
	margin: 0;
	padding: 0;
	width: 90px;
}

/* sociable overrides */

#sociable-links {
	white-space: nowrap;
}

#sociable-links a {
	margin-right: 4px;
}

#sociable-links a img { /* override to make sociable images not appear with a border */
	border: none;
}

/* technorati tag override for autometa plugin */
.technorati {
	display: none;
}

/* override for cc-configurator licensing information after posts and pages */

#license-slug { /* derived from .postmetadata */
	color: #999999;
	font-family: Georgia, Times New Roman, Times, serif;
	font-style: italic;
	font-size: 1em;
}

#license-slug img {
	float: right;
	margin-left: 4px;
}

/************** END THEMED OVERRIDES FOR PLUGINS *************/

