/* this is an ancillary theme companion for the admin interface -based on style.css */

/* typography/colors */

body {
	font-family: Tahoma, Arial, helvetica, sans-serif;
/* 	font-size: 80%; */ /* triggers a bug in mozilla regarding fieldset captions */
	color: #111145;
}
table,td,input {
	font-family: Tahoma, Arial, helvetica, sans-serif !important;
}

a:link, a:active {
	color: #0000b8;
}

a:visited {
	color: #606077;
}

h1, h2, h3, h4, h5, h6 {
	color: #0000b8;
	font-weight: normal;
	font-family: Tahoma, Arial, helvetica, sans-serif !important;
}

h1 {font-size: 1.45em}
h2 {font-size: 1.4em}
h3 {font-size: 1.25em}
h4 {font-size: 1.1em}
h5 {font-size: 1em}

h2 {
	border-bottom: 2px solid #adade3;
}

/* inline styles */

q { quotes: "«" "»" "‹" "›"; font-style: italic; }
abbr, acronym { border-bottom: 1px dashed #111145; }


/* block styles */

hr {
	height: 1px;
	background-color: #adade3;
	border: none;
}

ul { padding-left: 1em; }
ol { padding-left: 1.2em; }


/* style overrides for header */

body {
background: #F1F0FB;
}

.wrap {
/* background: url(images/semitransparent.png); */
background: white;
border: 1px inset #adade3;
padding-top: 1em;
padding-bottom: 1em;
}
.wrap *:first-child {
margin-top: 0;
}
.wrap *:last-child {
margin-bottom: 0;
}

#wphead {
	background: transparent;
	border: none;
	padding-bottom: 0.3em;
}

#wphead {
padding-bottom: 0px;
}

#wphead span {
	position: absolute;
	top: 0.90em;
	right: 0em;
	color: #F1F0FB; /* to hide the parentheses */
	/* float: right; */
	display: block;
/* 	margin-top: -2.25em; */
	margin-top: 0px !important;
	padding-top: 0px !important;
}

#adminmenu {
	background: transparent;
	margin-bottom: 0.3em;
	border: none;
	display: table;
/* 	margin-left: auto; */
/* 	margin-right: auto; */
	position: absolute;
/* 	float: right; */
	top: 0.6em;
	right: 7em;
	margin-top: 0px;
	padding-top: 0px;
/* 	margin-top: -2.75em; */
/* 	margin-right: 7.2em; */
}

#adminmenu a, #wphead a {
background: #E0E0F6;
border: 1px outset #adade3;
margin-left: 0.2em;
margin-right: 0.2em;
padding: 0.2em;
/* padding-right: 0.2em; */
font-size: 1.1em;
}
#adminmenu a:hover,#adminmenu a.current {
background: #F1F0FB;
border: 1px outset #adade3;
}
#adminmenu a.current {
background: white;
border: 1px inset #adade3;
}

#adminmenu2 {
	border-top: 2px solid #0000b8;
	background-color: white;
/* 	font-weight: bold; */
	padding-top: 0.7em;
}

#adminmenu2 a {
	color: #111145;
}

#adminmenu2 a.current {
	border: 1px outset #adade3;
	border-bottom: none;
}

#adminmenu2 a.current, #adminmenu2 a:hover {
	background: #F1F0FB;
}

/* end style overrides for header * /

/* controls styles */

form {
	margin: 0px;
	padding: 0px;
}

textarea {
	width: 100%;
}

input[type=text], input[type=password], input[type=file], select, textarea {
	border: 1px inset #adade3;
	background: #F1F0FB
}

label {
	background: transparent !important;
}

option {
	background-color: transparent;
	background-image: #F1F0FB !important;
}

input[type=hidden] {
	border: none;
	background: none;
}

input[type=submit], input[type=button], .submit input , .submit input:focus {
	border: 1px outset #adade3;
	background: #E0E0F6;
	color: #111145;
	
/* 	margin-top: 2px; */
/* 	margin-bottom: 2px; */
/* 	margin-left: 2px; */
/* 	margin-right: 2px; */
/* 	padding: 1px; */

}

input[type=submit]:active, input[type=button]:active, .button:active {
	border: 1px inset #adade3;
	background: #E0E0F6;
/* 	margin-top: 2px; */
/* 	margin-bottom: 2px; */
/* 	margin-left: 2px; */
/* 	margin-right: 2px; */
/* 	padding-top: 2px; */
/* 	padding-left: 2px; */
/* 	padding-right: 0px; */
/* 	padding-bottom: 0px; */

/* 	border-style: inset; */
}

/* .submit input , .submit input:focus { */
/* 	border: 1px outset #adade3; */
/* 	margin: 1px; */
/* 	background-color: #bbbbd2; */
/* 	color: #111145; */
/* } */


/* table display overrides */

th {background: #E0E0F6;}

.alternate {background: url(images/semitransparent-blue-light.png);}

.active {background: url(images/semitransparent-blue.png);}

.name, .vers, .auth, .desc, .togl {background: transparent !important;}

.updated {background: url(images/semitransparent-blue.png);border: 1px solid #adade3;}


/* my plugin's override for progress bar */
#validation-progress-bar-container {
border-color: #adade3 !important;
background: #F1F0FB !important;
}

#validation-progress-bar {
border-color: #adade3 !important;
background: #adade3 !important;
}

/* zeitgeist override */

#zeitgeist {
 background-color: white;
border: 1px outset #adade3;

}


/* quicktags */


/* Button Style */
#quicktags input.ed_button {
	background: #F1F0FB;
	border: 1px outset #adade3;
	font-family: Georgia, "Times New Roman", Times, serif;
	margin: 1px;
	width: auto;
}
/* Button Style on focus/click */
#quicktags input:focus.ed_button {
	background: #FFFFFF;
	border: 1px solid #686868;
}
/* Button Lable style */
#quicktags #ed_strong {
	font-weight: bold;
}
/* Button Lable style */
#quicktags #ed_em {
	font-style: italic;
}
