<?php
/*
Template Name: Archives
*/
?><?php get_header(); ?>

<div id="content">

<h1 class="pagetitle">Complete archives</h1>

<div>
<h2 style="text-align: center;">Search the archives</h2>

<?php include (TEMPLATEPATH . '/searchform.php'); ?>
</div>

<!-- google_ad_section_start -->

<table width="100%" border="0">
<tr>
<td valign="top">
<h2>Articles by month:</h2>
  <p class="postmetadata"><a href="#by-category">(Skip to articles by category)</a></p>
  <ul>
    <?php wp_get_archives('type=monthly&show_post_count=1'); ?>
  </ul>
<h2 id="by-category">Articles by category:</h2>
  <ul>
     <?php wp_list_cats('sort_column=name&optioncount=1&hierarchical=1'); ?>
  </ul>
</td>
<td valign="top" width="10">
&nbsp;
</td>
<td valign="top">
<h2>Web pages in this site:</h2>
  <ul>
     <?php wp_list_pages("title_li=&sort_column=menu_order"); ?>
  </ul>
</td>
</tr>
</table>

<!-- google_ad_section_end -->

</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>
