<?php get_header(); ?>

	<div id="content">

		<h1 class="pagetitle"><?php echo revvedup_get_http_error_title(); ?></h1>
		<div class="information"><?php echo revvedup_get_http_error_description(); ?></div>

	</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>