/**** AD STYLES *****/

@media print {
	.ad-after-content, .ad-after-title, .ad-intermixed, .ad-tip-block, .ad-sidebar, .ad-header, .ad-referral .ad-left-of-content, .ad-right-of-content {
		display: none;
	}
}

.ad-after-content, .ad-after-title {
	text-align: center;
	margin-top: 1em;
}

.ad-intermixed {
        text-align: center;
	margin-top: -1.5em;
	margin-bottom: 1.5em;
}

.ad-tip-block {
}

.ad-left-of-content {
	float: left;
	margin-left: -10px;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

.ad-right-of-content {
	float: right;
	margin-left: 0.5em;
	margin-right: -10px;
	margin-bottom: 0.5em;
}

.ad-sidebar {
	margin-top: 1em;
}

.ad-header {
	position: absolute;
	top: 0px;
	left: 0px;
	margin-top: 20px;
	margin-left: 20px;
}

.ad-referral {
	text-align: center;
	margin-bottom: 20px;
	padding-top: 10px;
}

/******* END AD STYLES ********/
